summaryrefslogtreecommitdiffstats
path: root/testsuite/check.sh
diff options
context:
space:
mode:
Diffstat (limited to 'testsuite/check.sh')
-rwxr-xr-xtestsuite/check.sh3
1 files changed, 2 insertions, 1 deletions
diff --git a/testsuite/check.sh b/testsuite/check.sh
index 3fc9f12..7ed18f4 100755
--- a/testsuite/check.sh
+++ b/testsuite/check.sh
@@ -1,5 +1,5 @@
#! /bin/sh
# check script for Xlunzip - Test tool for the lunzip linux module
# Copyright (C) 2016-2018 Antonio Diaz Diaz.
#
# This script is free software: you have unlimited permission
@@ -129,6 +129,7 @@ cmp in2 copy2 || test_failed $LINENO
cat in2.lz > copy2.lz || framework_failure
printf "\ngarbage" >> copy2.lz || framework_failure
+"${LZIP}" -tvvvv copy2.lz 2> /dev/null || test_failed $LINENO
printf "to be overwritten" > copy2 || framework_failure
"${LZIP}" -df copy2.lz || test_failed $LINENO
cmp in2 copy2 || test_failed $LINENO
@@ -1,5 +1,5 @@
#! /bin/sh
-# check script for Xlunzip - Test tool for the lunzip linux module
+# check script for Xlunzip - Test tool for the lzip_decompress linux module
# Copyright (C) 2016-2018 Antonio Diaz Diaz.
#